@@ -27,7 +27,11 @@ class AdamApiError( Exception ):
 
 class AdamApiMessage( Exception ):
     """Base class for adamapi mesage"""
-    pass
+    def __init__(self,json):
+        self.pk=json["pk"]
+        self.status=json["status"]
+        self.location = json["location"] if "location" in json else ""
+
 
 from . import authorization
 from . import datasets
